@@ -1,6 +1,9 @@
 from .wrapper.dingtalk import DingTalkBot
 from .wrapper.wecom import WeComBot
 from .wrapper.feishu import FeishuBot
+from .wrapper.slack import SlackBot
 
 from .server import OmniUniBotServer
 from .client import OmniUniBotClient
+
+from .__version__ import __version__
